Numeric. Vector of numeric pump IDs to subset from the neighborhoods defined by pump.select. Negative selection possible. NULL uses all pumps in pump.select.
pump.select
Numeric. Numeric vector of pump IDs that define which pump neighborhoods to consider (i.e., specify the "population"). Negative selection possible. NULL selects all pumps.
metric
Character. Type of neighborhood: "euclidean" or "walking".
type
Character. Type of case: "stack.base" (base of stack), or "stack" (entire stack). For observed = TRUE.
token
Character. Type of token to plot: "point" or "id".
text.size
Numeric. Size of case ID text.
pch
Numeric.
point.size
Numeric.
vestry
Logical. TRUE uses the 14 pumps from the Vestry Report. FALSE uses the 13 in the original map.
weighted
Logical. TRUE computes shortest walking path weighted by road length. FALSE computes shortest walking path in terms of the number of nodes.
color
Character. Use a single color for all paths. NULL uses neighborhood colors defined by snowColors().
Numeric. Alpha level transparency for area plot: a value in [0, 1].
multi.core
Logical or Numeric. TRUE uses parallel::detectCores(). FALSE uses one, single core. You can also specify the number logical cores. See vignette("Parallelization") for details.