This data set transforms Dodson and Tobler's street data to give each straight line segment of a "road" a unique ID.
frame.segmentsA data frame with 658 observations and 7 variables. The data describe the straight line segments used to recreate the roads on Snow's map.
streetnumeric street ID
idcharacter segment ID
nameroad name
x1x-coordinate of first endpoint
y1y-coordinate of first endpoint
x2x-coordinate of second endpoint
y2y-coordinate of second endpoint
lon1longitude of first endpoint
lat1latitude of first endpoint
lon2longitude of second endpoint
lat2latitude of second endpoint