Learn R Programming

cholera (version 0.7.0)

orthogonalProjection: Compute coordinates of orthogonal projection from case to road segment.

Description

Compute coordinates of orthogonal projection from case to road segment.

Usage

orthogonalProjection(case = 12, segment.id = "216-1",
  observed = TRUE, use.pump = FALSE, vestry = FALSE,
  case.data = NULL)

Arguments

case

Numeric. case ID from fatalities.

segment.id

Character. Road segment ID.

observed

Logical. FALSE observed case; TRUE simulated case (regular.cases).

use.pump

Logical. Use pump ID as case.

vestry

Logical. Use vestry pump data.

case.data

Object. For use with simulateFatalities.

Value

An R data frame.